@@ -72,7 +72,7 @@ class R3sponse(object):
 		variable = request.GET.get(identifier)
 		if variable in ["", None]:
 			return variable, self.error_response(f"Define parameter: [{identifier}].")
-		return variable, self.success_response(f"Succesfully retrieved request parameter [{name}].")
+		return variable, self.success_response(f"Succesfully retrieved request parameter [{identifier}].")
 	def get_request_parameters(self, request, identifiers=[], optional=False):
 		if isinstance(identifiers, str):
 			return self.error_response("__get_request_params__ is used to retrieve several identifiers (array format not string).")
@@ -102,6 +102,28 @@ class R3sponse(object):
 		return response
 
 	# log functions.
+	def log(self, 
+		# option 1:
+		# the message.
+		message=None,
+		# option 2:
+		# the response dict (leave message None to use).
+		response={},
+		# optionals:
+		# save to log file.
+		save=False,
+	):
+		msg = None
+		if [message,response] == [None,{}]:
+			raise ValueError("Define either parameter [message:str] or [response:dict].")
+		if response != None:
+			if response["error"] != None: msg = f"Error: {response['error']}"
+			else: msg = response['message']
+		else: msg = message
+		print(utils.color.fill(msg))
+		if save: self.__log_to_file__(msg)
+
+		#
 	def load_logs(self, format="webserver", options=["webserver", "cli", "array", "string"]):
 		try:
 			logs = Formats.File(self.log_file, load=True, blank="").data
